export declare const contentDir: string;
/** enclosing directory for a given tutorial */
export declare const projectHome: (projectName: any) => string;
interface TutorialNextSteps {
    command: string;
    display?: string;
    doc: string;
    when: string;
    hidden?: boolean;
}
export interface TutorialTable {
    title: string;
    columns: string[];
    rows: [{
        value: string;
        when: string;
        onclick: () => void;
    }, string][];
}
interface TutorialStepExtras {
    alternate?: TutorialNextSteps[];
    nextSteps?: TutorialNextSteps[];
    table?: TutorialTable;
    learnMore?: {
        title: string;
        doc: string;
    };
    code?: {
        language: string;
        body: string;
    };
    showcase?: {
        title: string;
        command: string;
        display?: string;
        description: string;
        image: string;
        groupWith?: string;
    }[];
}
interface TutorialStep {
    heading: string;
    content: string;
    transition: string;
    input: {
        selector: string;
        value: string;
    };
    extras?: TutorialStepExtras;
    renderingHints?: string;
    fontawesome?: string;
    highlight?: {
        selector: string;
    };
    autocomplete?: {
        selector: string;
        value: string;
    };
    execute?: string;
    preview?: {
        file: string;
    };
    sidecar?: string;
}
export interface TutorialDefinition {
    fullscreen: boolean;
    height?: string;
    skills?: string[];
    steps: TutorialStep[];
}
interface Tutorial {
    config: {
        name: string;
        projectName: string;
        tutorial: TutorialDefinition;
    };
    tutorial: TutorialDefinition;
}
/**
 * Read the module metadata
 *
 */
export declare const readProject: (projectHome: string) => Promise<Tutorial>;
export {};
