"use strict";
/*
 * Copyright 2018 IBM Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const Debug = require("debug");
const path_1 = require("path");
const debug = Debug('plugins/tutorials/utils');
/** enclosing directory for tutorials */
const top = path_1.dirname(require.resolve('@kui-shell/plugin-tutorials/package.json'));
exports.contentDir = path_1.join(top, 'samples/@tutorials');
/** enclosing directory for a given tutorial */
exports.projectHome = projectName => path_1.join(exports.contentDir, projectName);
// eslint-disable-next-line @typescript-eslint/no-explicit-any
const readJSON = (projectHome, fileName) => new Promise((resolve, reject) => {
    debug('readJSON');
    try {
        if (projectHome.indexOf('@tutorials') >= 0) {
            const projectName = path_1.basename(projectHome);
            debug('reading built-in', projectName, fileName);
            // WARNING: webpack requires that the path prefix be an explicit string :(
            // DO NOT try to be clever here
            resolve(require('@kui-shell/plugin-tutorials/samples/@tutorials/' + projectName + '/' + fileName));
        }
        else {
            debug('reading external', projectHome, fileName);
            resolve(path_1.join(projectHome, fileName));
        }
    }
    catch (err) {
        reject(err);
    }
});
/**
 * Read the module metadata
 *
 */
exports.readProject = (projectHome) => __awaiter(this, void 0, void 0, function* () {
    debug('readProject', projectHome);
    if (path_1.basename(projectHome) === 'package.json') {
        // maybe the user specified the filepath of the package.json?
        return exports.readProject(path_1.dirname(projectHome));
    }
    return Promise.all([readJSON(projectHome, 'package.json'), readJSON(projectHome, 'tutorial.json')]).then(([config, tutorial]) => {
        return {
            config: Object.assign({}, { projectName: config.name }, config),
            tutorial,
            projectHome
        };
    });
});
//# sourceMappingURL=util.js.map